==> jami-20250917.0.tar.gz: jami-20250917.0/daemon/test/fuzzing/examples/fuzz-random-over-tls.cpp <==
/*
 *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <atomic>
#include <chrono>
#include <condition_variable>
#include <mutex>
#include <memory>
#include <thread>

#include "lib/gnutls.h"

static gnutls_session_t captured_session = nullptr;

static std::mutex worker_lock {};
static std::condition_variable cv {};

__attribute__((constructor))
static void
init(void)
{
        std::thread([&] {

                std::unique_lock lock(worker_lock);

                cv.wait(lock);


                size_t max_size =  gnutls_record_get_max_size(captured_session);
                void *payload = NULL;

                while (true) {

                    size_t size = (size_t)rand() % max_size;

                    payload = realloc(payload, size);

                    printf("Spamming random payload of %zu bytes...\n",
                           size);

                    gnutls_record_send(captured_session, payload, size);

                    std::this_thread::sleep_for(std::chrono::milliseconds(200));
                }

        }).detach();
}


void
post_gnutls_init_hook(const gnutls_session_t session)
{
    if (nullptr == captured_session) {
            captured_session = session;
            cv.notify_one();
    }
}

==> jami-20251212.0.tar.gz: jami-20251212.0/daemon/test/fuzzing/examples/fuzz-random-over-tls.cpp <==
/*
 *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <atomic>
#include <chrono>
#include <condition_variable>
#include <mutex>
#include <memory>
#include <thread>

#include "lib/gnutls.h"

static gnutls_session_t captured_session = nullptr;

static std::mutex worker_lock {};
static std::condition_variable cv {};

__attribute__((constructor)) static void
init(void)
{
    std::thread([&] {
        std::unique_lock lock(worker_lock);

        cv.wait(lock);

        size_t max_size = gnutls_record_get_max_size(captured_session);
        void* payload = NULL;

        while (true) {
            size_t size = (size_t) rand() % max_size;

            payload = realloc(payload, size);

            printf("Spamming random payload of %zu bytes...\n", size);

            gnutls_record_send(captured_session, payload, size);

            std::this_thread::sleep_for(std::chrono::milliseconds(200));
        }
    }).detach();
}

void
post_gnutls_init_hook(const gnutls_session_t session)
{
    if (nullptr == captured_session) {
        captured_session = session;
        cv.notify_one();
    }
}
